@@ -36,10 +36,6 @@ def ip_address_from_request(request):
 
     return ip_address
 
-def get_visitor(visitor_key):
-    """ get the visitor using the visitor key """
-    return Visitor.objects.find_visitor(visitor_key)
-
 def create_visitor(ip_address,session_key):
     """ Create the visitor given an ip_address """
     visitor = Visitor()
